@@ -11,23 +11,38 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Fake module support
+"""Fake module support.
+
+See :doc:`../module` for documentation.
 """
 
 import sys
 
-class FakeModule(object):
+
+__all__ = [
+    'setUp',
+    'tearDown',
+]
+
+
+class FakeModule:
     def __init__(self, dict):
         self.__dict = dict
+
     def __getattr__(self, name):
         try:
             return self.__dict[name]
         except KeyError:
             raise AttributeError(name)
+
     def __dir__(self):
         return self.__dict.keys()
 
+
 def setUp(test, name='__main__'):
+    """
+    Replace the module named *name* with a fake version.
+    """
     dict = test.globs
     dict['__name__'] = name
     module = FakeModule(dict)
@@ -37,7 +52,11 @@ def setUp(test, name='__main__'):
         parent = sys.modules['.'.join(name[:-1])]
         setattr(parent, name[-1], module)
 
+
 def tearDown(test, name=None):
+    """
+    Remove the (fake) module named *name*.
+    """
     if name is None:
         name = test.globs['__name__']
     del test.globs['__name__']
